﻿//------------------------------------------------------------------------------
//
//  Cloud File System for Azure サンプルプログラム
//
//  注意：本プログラムは、サンプルプログラムのため、
//        エラーチェックや戻り値チェック等は行っていませんので、ご注意ください。
//        
//  Copyright (c) 2011 AYA Software Co.,Ltd. All rights reserved.
//
//  2011/06/04  Rev.1.00    AYA     初版作成
//
//------------------------------------------------------------------------------
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using AYA_Software.AzureSystem;

namespace Sample
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        AzureFileSystem myFileSystem;      // クラス宣言

        // 接続
        private void cmdConnect_Click(object sender, EventArgs e)
        {
            string myConnStr = "DefaultEndpointsProtocol=https;AccountName=" + textAccountName.Text + ";AccountKey=" + textAccountKey.Text;
            try
            {
                myFileSystem = new AYA_Software.AzureSystem.AzureFileSystem(myConnStr, textContainerName.Text, (Int64)numMaxSize.Value);
                if (myFileSystem != null)
                {
                    cmdConnect.Enabled = false;
                    cmdDisconnect.Enabled = true;
                    groupBox2.Enabled = true;
                    groupBox3.Enabled = true;
                    treeFolder.SelectedNode = treeFolder.Nodes[0];              // ルートを選択
                };
            }
            catch
            {
                MessageBox.Show("接続に失敗しました");
            };
        }

        // 切断
        private void cmdDisconnect_Click(object sender, EventArgs e)
        {
            cmdConnect.Enabled = true;
            cmdDisconnect.Enabled = false;
            groupBox2.Enabled = false;
            groupBox3.Enabled = false;
        }

        // ツリー再描画
        private void cmdRedrawFolder_Click(object sender, EventArgs e)
        {
            myFileSystem.AddCloudDirectoryTree(this.treeFolder.Nodes[0].Nodes, "/");
        }

        // ツリー選択時
        private void treeFolder_AfterSelect(object sender, TreeViewEventArgs e)
        {
            cmdRedrawFile_Click(sender, null);
        }

        // リスト再描画
        private void cmdRedrawFile_Click(object sender, EventArgs e)
        {
            List<string> myList = new List<string>();

            listFile.Items.Clear();
            myList = myFileSystem.GetCloudFileAndDirectory(treeFolder.SelectedNode.FullPath, false, false);
            foreach (string myItem in myList)
            {
                ListViewItem myListItem = new ListViewItem();
                myListItem.Text = (listFile.Items.Count + 1).ToString();
                myListItem.SubItems.Add(myItem);
                listFile.Items.Add(myListItem);
            };
        }

        // ファイルアップロード
        private void cmdUploadFile_Click(object sender, EventArgs e)
        {
            ENUM_OVERWRITEKIND myOverwrite = ENUM_OVERWRITEKIND.SHOWDIALOG;
            List<EventInfo> myEvent = new List<EventInfo>();

            if (myFileSystem != null)
            {
                if (openFileDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    myFileSystem.UploadFile(openFileDialog1.FileName, treeFolder.SelectedNode.FullPath, ref myOverwrite, ref myEvent);
                    MessageBox.Show("UploadFile完了");
                };
            };
        }

        // フォルダアップロード
        private void cmdUploadFolder_Click(object sender, EventArgs e)
        {
            ENUM_OVERWRITEKIND myOverwrite = ENUM_OVERWRITEKIND.SHOWDIALOG;
            List<EventInfo> myEvent = new List<EventInfo>();

            if (myFileSystem != null)
            {
                if (folderBrowserDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    var myUploadFolder = treeFolder.SelectedNode.FullPath + System.IO.Path.GetFileName(folderBrowserDialog1.SelectedPath);
                    myFileSystem.UploadFolder(folderBrowserDialog1.SelectedPath, myUploadFolder, ref myOverwrite, ref myEvent);
                    MessageBox.Show("UploadFolder完了");
                };
            };
        }

        // ファイルダウンロード
        private void cmdDownloadFile_Click(object sender, EventArgs e)
        {
            ENUM_OVERWRITEKIND myOverwrite = ENUM_OVERWRITEKIND.SHOWDIALOG;
            List<EventInfo> myEvent = new List<EventInfo>();

            if (myFileSystem != null)
            {
                saveFileDialog1.FileName = listFile.SelectedItems[0].SubItems[1].Text;
                if (saveFileDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    var myCloudPath = treeFolder.SelectedNode.FullPath + "/" + listFile.SelectedItems[0].SubItems[1].Text;
                    myFileSystem.DownloadFile(myCloudPath, saveFileDialog1.FileName, ref myOverwrite, ref myEvent);
                    MessageBox.Show("DownloadFile完了");
                };
            };
        }

        // フォルダダウンロード
        private void cmdDownloadFolder_Click(object sender, EventArgs e)
        {
            ENUM_OVERWRITEKIND myOverwrite = ENUM_OVERWRITEKIND.SHOWDIALOG;
            List<EventInfo> myEvent = new List<EventInfo>();

            if (myFileSystem != null)
            {
                if (folderBrowserDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    var myDownloadFolder = folderBrowserDialog1.SelectedPath + "\\" + LibAzure.GetLastToken(treeFolder.SelectedNode.FullPath);
                    myFileSystem.DownloadFolder(treeFolder.SelectedNode.FullPath, myDownloadFolder, ref myOverwrite, ref myEvent);
                    MessageBox.Show("DownloadFolder完了");
                };
            };
        }

        // ファイル削除
        private void cmdDeleteFile_Click(object sender, EventArgs e)
        {
            if (myFileSystem != null)
            {
                var myCloudPath = treeFolder.SelectedNode.FullPath + "/" + listFile.SelectedItems[0].SubItems[1].Text;
                myFileSystem.DeleteFile(myCloudPath);
                MessageBox.Show("DeleteFile完了");
            };
        }

        // フォルダ削除
        private void cmdDeleteFolder_Click(object sender, EventArgs e)
        {
            if (myFileSystem != null)
            {
                myFileSystem.DeleteFolder(treeFolder.SelectedNode.FullPath);
                MessageBox.Show("DeleteFolder完了");
            };
        }

        // ファイルオープン
        private void cmdOpenFile_Click(object sender, EventArgs e)
        {
            var myCloudPath = treeFolder.SelectedNode.FullPath + "/" + listFile.SelectedItems[0].SubItems[1].Text;
            myFileSystem.OpenFile(myCloudPath, true);
            MessageBox.Show("OpenFile完了");
        }

        // ファイル情報取得
        private void cmdFileProperty_Click(object sender, EventArgs e)
        {
            var myCloudPath = treeFolder.SelectedNode.FullPath + "/" + listFile.SelectedItems[0].SubItems[1].Text;
            var myFileInfo = myFileSystem.CloudFileExists(myCloudPath);
            MessageBox.Show("サイズ：" + myFileInfo.FileSize.ToString("#,##0\r\n") +
                "更新日時：" + myFileInfo.LastWriteTime.ToString("yyyy/MM/dd HH:mm:ss\r\n") + 
                "作成日時：" + myFileInfo.CreationTime.ToString("yyyy/MM/dd HH:mm:ss\r\n") + 
                "アクセス日時：" + myFileInfo.LastAccessTime.ToString("yyyy/MM/dd HH:mm:ss"));
        }

    }
}
